@@ -20,9 +20,9 @@ from progressbar import ProgressBar
 
 import dzclient
 import gaiatest
+from marionette import Actions
 from marionette import Marionette
-from marionette import MarionetteTouchMixin
-from gestures import smooth_scroll
+from marionette.gestures import smooth_scroll
 
 from wait import MarionetteWait
 
@@ -222,7 +222,14 @@ class B2GPerfRunner(DatazillaPerfPoster):
                 if self.submit_report:
                     self.post_to_datazilla(results, app_name)
                 else:
-                    print 'Results: %s' % results
+                    print 'Results for %s:' % app_name
+                    for key, values in results.iteritems():
+                        print '* %s: avg:%s, max:%s, min:%s, all:%s' % (
+                            key,
+                            sum(values) / len(values),
+                            max(values),
+                            min(values),
+                            ','.join(str(x) for x in values))
 
             except Exception:
                 traceback.print_exc()
@@ -329,21 +336,31 @@ class B2GPerfRunner(DatazillaPerfPoster):
 
     def scroll_app(self, app_name):
         touch_duration = float(200)
-        self.marionette.__class__ = type('Marionette', (Marionette, MarionetteTouchMixin), {})
 
-        self.marionette.setup_touch()
         apps = gaiatest.GaiaApps(self.marionette)
         #wait up to 30secs for the elements we want to show up
         self.marionette.set_search_timeout(30000)
 
         if app_name == 'Homescreen':
-            self.marionette.flick(self.marionette.find_element('id', 'landing-page'), '90%', '50%', '10%', '50%', touch_duration)
-            time.sleep(touch_duration / 1000)
-            self.marionette.flick(self.marionette.find_elements('css selector', '.page')[1], '10%', '50%', '90%', '50%', touch_duration)
+            action = Actions(self.marionette)
+            landing_page = self.marionette.find_element('id', 'landing-page')
+            action.flick(
+                landing_page,
+                landing_page.size['width'] / 100 * 90,
+                landing_page.size['width'] / 2,
+                landing_page.size['width'] / 100 * 10,
+                landing_page.size['width'] / 2, touch_duration).perform()
+            first_page = self.marionette.find_elements('css selector', '.page')[1]
+            action.flick(
+                first_page,
+                first_page.size['width'] / 100 * 10,
+                first_page.size['width'] / 2,
+                first_page.size['width'] / 100 * 90,
+                first_page.size['width'] / 2, touch_duration).perform()
         elif app_name == 'Contacts':
             name = self.marionette.find_element("class name", "contact-item")
             MarionetteWait(self.marionette, 30).until(lambda m: name.is_displayed() or not name.get_attribute('hidden'))
-            smooth_scroll(self.marionette, name, "y", "negative", 5000, scroll_back=False)
+            smooth_scroll(self.marionette, name, "y", -1, 5000, scroll_back=False)
         elif app_name == 'Browser':
             self.marionette.execute_script("return window.wrappedJSObject.Browser.navigate('http://taskjs.org/');", new_sandbox=False)
             MarionetteWait(self.marionette, 30).until(lambda m: 'http://taskjs.org/' == m.execute_script('return window.wrappedJSObject.Browser.currentTab.url;', new_sandbox=False))
@@ -356,7 +373,7 @@ class B2GPerfRunner(DatazillaPerfPoster):
             self.marionette.switch_to_frame()
             apps.launch(app_name)  # since the app is launched, launch will switch us back to the app frame without relaunching
             tab_dom = self.marionette.execute_script("return window.wrappedJSObject.Browser.currentTab.dom;", new_sandbox=False)
-            smooth_scroll(self.marionette, tab_dom, "y", "negative", 5000, scroll_back=True)
+            smooth_scroll(self.marionette, tab_dom, "y", -1, 5000, scroll_back=True)
         elif app_name == 'Email':
             email = self.marionette.find_element("class name", "msg-header-author")
             MarionetteWait(self.marionette, 30).until(lambda m: email.is_displayed() or not email.get_attribute('hidden'))
@@ -364,7 +381,7 @@ class B2GPerfRunner(DatazillaPerfPoster):
             #we're dynamically adding these elements from a template, and the first one found is blank.
             MarionetteWait(self.marionette, 30).until(lambda m: emails[0].get_attribute('innerHTML'))
             emails = self.marionette.find_elements("class name", "msg-header-author")
-            smooth_scroll(self.marionette, emails[0], "y", "negative", 2000, scroll_back=True)
+            smooth_scroll(self.marionette, emails[0], "y", -1, 2000, scroll_back=True)
 
 
 class dzOptionParser(OptionParser):
